:Note: This goldstandard was extracted from 
    from D4C1 challenge page (https://www.synapse.org/#!Synapse:syn2925957).
    Note that one of the 13 matrices is not filled properly. The GS for that
    matrix (4th) was not available at the time of the scoring.

